import cv2
import os
import shutil

# get the path to the images folder relative to the script's directory
folder_path = "./images/sdo/"

# get a list of all the files in the folder
files = os.listdir(folder_path)

# sort the files alphabetically to ensure the frames of the video are in order
files.sort()

# create a list to hold all the image frames
frames = []

# loop through all the files and add each image as a frame
for file in files:
    # make sure we're only processing image files
    if file.endswith(".jpg") or file.endswith(".png") or file.endswith(".jpeg"):
        # read in the image using OpenCV and add it to the frames list
        img = cv2.imread(os.path.join(folder_path, file))
        frames.append(img)

# get the dimensions of the first frame to use for the output video
height, width, channels = frames[0].shape

# create a VideoWriter object to write the output video
fourcc = cv2.VideoWriter_fourcc(*'XVID')  # use XVID codec for AVI format
out = cv2.VideoWriter('sdo.avi', fourcc, 24.0, (width, height), isColor=True)

# write each frame to the output video
for frame in frames:
    out.write(frame)

# release the VideoWriter object and close all windows
out.release()
cv2.destroyAllWindows()

# Set the original output file path
original_path = 'sdo.avi'

# Set the new output file path
new_path = './images/sdo.avi'

# Move the file to the new location
shutil.move(original_path, new_path)




#get what we need
import urllib.request
import os

#set up new working directory && create folders
script_directory = os.path.dirname(os.path.abspath(__file__))
os.chdir(script_directory)
os.system(r"python makem.py")

os.system('cls' if os.name == 'nt' else 'clear')

def get_proton():
    # Set up the URL for the text file
    url = "https://services.swpc.noaa.gov/text/ace-swepam.txt"
    
    # Download the text file
    response = urllib.request.urlopen(url)
    data = response.read().decode()
    
    # Split the text file into lines
    lines = data.split("\n")

    # Extract the most recent solar wind data from the second-to-last line
    last_line = lines[-2]
    fields = last_line.split()

    # Extract the solar wind speed, density, and temperature from the fields
    s = float(fields[6])
    density = float(fields[7])
    speed = float(fields[8])
    temperature = (fields[9])
    
    #returning values
    return s, speed, density, temperature
    
def get_gsm():
    # Set up the URL for the text file
    url = "https://services.swpc.noaa.gov/text/ace-magnetometer.txt"
    
    # Download the text file
    response = urllib.request.urlopen(url)
    data = response.read().decode()
    
    # Split the text file into lines
    lines = data.split("\n")
    
    # Extract the most recent Interplanetary Magnetic Field data from the second-to-last line
    last_line = lines[-2]
    fields = last_line.split()
    
    # Extract the Bx, By, Bz, Bt data from the fields
    S =  float(fields[6])
    Bx = float(fields[7])
    By = float(fields[8])
    Bz = float(fields[9])
    Bt = float(fields[10])
    
    #return all collected values
    return S, Bx, By, Bz, Bt
   
def get_report():
    # Set up the URL for the text file
    url = "https://services.swpc.noaa.gov/text/discussion.txt"
    
    # Download the text file
    response = urllib.request.urlopen(url)
    report = response.read().decode()
    return(report)
    

def main():
    
    os.system(r"python makem.py")

    #Present Options
    print("Welcome to the Interplanetary Space Weather Interface, \nThis data is collected by the Advanced Composition Explorer (ACE). \n\nYou have the following options: \n")
    print("1.) Space Weather Prediction Center Forecast Report")
    print("2.) 1-Minute Averaged Real-time Interplanetary Solar Wind Plasma Data")
    print("3.) 1-Minute Averaged Real-time Interplanetary Magnetic Field Data")
    print("4.) Download Today's 193 Angstrom Images from NASA Solar Dynamics Observatory")
    print("5.) Donwload Today's SOHO Coronograph Imagery")
    
    #Get User Choice
    choice = input("Enter a number corresponding to an option above: ")
    
    #printing values
    
    if choice == "1":
    
        #clean up screen
        os.system('cls' if os.name == 'nt' else 'clear')
        
        report = get_report()
        print("\n")
        print(report)
        print("\n")
        
        #prepare for follow on mission
        input("Press Enter to continue...")
        os.system('cls' if os.name == 'nt' else 'clear')
        main()
    
    elif choice == "2":
    
        #clean up screen
        os.system('cls' if os.name == 'nt' else 'clear')
        
        #update values
        s, speed, density, temperature = get_proton()
        
        #Print Information
        print("\nLatest data on Solar Wind Plasma (Protons) at the L1 Lagrange is below \n")
        
        #Account for Errors
        if s != 0:
            print("ERROR EITHER BAD DATA OR NO DATA \nTRY AGAIN IN 1 MINUTE")
        
        #print data
        else:
            print("Speed: ", speed, "km/s")
            print("Density: ", density, "protons/cm^3")
            print("Temperature: ", temperature, "K")
        
        #prepare for follow on mission
        input("Press Enter to continue...")
        os.system('cls' if os.name == 'nt' else 'clear')
        main()
        
    
    elif choice == "3":
        
        #clean up screen
        os.system('cls' if os.name == 'nt' else 'clear')
        
        print("\nLatest Data on Interplanetary Magnetic Field Values (GSM Coordinates): \n")
        S, Bx, By, Bz, Bt = get_gsm()
        
        if S != 0:
            print("ERROR EITHER BAD DATA OR NO DATA \nTRY AGAIN IN 1 MINUTE")
        
        else:
            print("Magnetic Field Strength in the X direction: ", Bx, "nT")
            print("Magnetic Field Strength in the Y direction: ", By, "nT")
            print("Magnetic Field Strength in the Z direction: ", Bz, "nT")
            print("Total Magnetic Field Magnitude: ", Bt, "nT \n")
        
        #prepare for follow on mission
        input("Press Enter to continue...")
        os.system('cls' if os.name == 'nt' else 'clear')
        main()
        
    elif choice == "4":
        
        #clean up screen
        os.system('cls' if os.name == 'nt' else 'clear')
        
        #call the sdo image getter
        os.system(r"python sdo_image_getter.py")
        
        print("You have successfully downloaded the images, would you like to generate an AVI from them?")
        movie = input("Enter \"y\" for Yes and \"n\" for No:  ")
        if movie == "y":
            print("The movie is now being generated. Please be Patient \n")
            os.system(r"python sdo_movie.py")
            os.system('cls' if os.name == 'nt' else 'clear')
            main()
            
        elif movie == "n":
            os.system('cls' if os.name == 'nt' else 'clear')
            os.system('cls' if os.name == 'nt' else 'clear')
            main()
            
    elif choice == "5":
        
        #clean up screen
        os.system('cls' if os.name == 'nt' else 'clear')
        
        #call the SOHO image gettter
        os.system(r"python soho_image_getter.py")
        
        print("You have successfully downloaded the images, would you like to generate an AVI from them?")
        movie = input("Enter \"y\" for Yes and \"n\" for No:  ")
        if movie == "y":
            print("The movie is now being generated. Please be Patient \n")
            os.system(r"python soho_movie.py")
            os.system('cls' if os.name == 'nt' else 'clear')
            main()
            
        elif movie == "n":
            os.system('cls' if os.name == 'nt' else 'clear')
            os.system('cls' if os.name == 'nt' else 'clear')
            main()
    
    
    else:
        os.system('cls' if os.name == 'nt' else 'clear')
        print("Please try again")
        main()



# we need to make some god damn directories so python doesn't flip out
import os

def makem():
	#lets make sure the dirs exist
	dir1 = './images/'

	if os.path.exists(dir1):
		pass
	else:
		# Create the new directory
		os.mkdir(dir1)

	dir2 = './images/sdo'
	dir3 = './images/soho'

	# Check if the directory already exists
	if os.path.exists(dir2):
		pass
	else:
		# Create the new directory
		os.mkdir(dir2)
			
	if os.path.exists(dir3):
		pass
	else:
		# Create the new directory
		os.mkdir(dir3)
makem()


import urllib.request
import os
import re

#on some computers there seems to be an error with SSL handling, this should ensure secure connections over SSL
import ssl; ssl._create_default_https_context = ssl._create_stdlib_context

# get current date
from datetime import date
today = date.today()
year = today.strftime("%Y")
month = today.strftime("%m")
day = today.strftime("%d")
path = './images/soho'
date = f"{year}{month}{day}"

image_list = []

for filename in os.listdir(path):
    # check if the file extension is an image extension
    if filename.lower().endswith(('.png', '.jpg', '.jpeg', '.bmp', '.gif')):
        # if it is, add the filename to the list
        image_list.append(filename)

# specify url and download directory
url = f"https://umbra.nascom.nasa.gov/pub/incoming/lasco/rtmovie_png/"
download_directory = "./images/soho/"

# create download directory if it doesn't exist
if not os.path.exists(download_directory):
    os.makedirs(download_directory)

# download images with filenames containing "date" and "c2"
with urllib.request.urlopen(url) as response:
    html = response.read().decode()
    pattern = re.compile(r'href="(.*?\.png)"')
    for match in pattern.finditer(html):
        filename = match.group(1)
        if date in filename and "c2" in filename and filename not in image_list:
            image_url = url + filename
            urllib.request.urlretrieve(image_url, download_directory + filename)
            print(f"Downloaded {filename}")



from setuptools import setup

VERSION = '1.0.12'
DESCRIPTION = 'Displays Space Weather Data, and downloads and compiles images of the sun into videos.'

# Setting up
setup(
    name="Space-Weather-Interface-P",
    version=VERSION,
    author="Stefan Randow",
    author_email="mail@example.com",
    description=DESCRIPTION,
    install_requires=['opencv-python'],
    keywords=['python', 'video'],
    entry_points={
        'console_scripts': [
            'SpaceWeather = Space_Weather_Interface_P.main:main',
        ],
    },
)
